JBoss Rich Faces SVN: r3346 - trunk/ui/separator/src/main/templates.
by richfaces-svn-commits@lists.jboss.org
Author: nbelaevski
Date: 2007-10-12 12:09:15 -0400 (Fri, 12 Oct 2007)
New Revision: 3346
Modified:
trunk/ui/separator/src/main/templates/separator.jspx
Log:
Duplicate align attribute in separator fixed
Modified: trunk/ui/separator/src/main/templates/separator.jspx
===================================================================
--- trunk/ui/separator/src/main/templates/separator.jspx 2007-10-12 15:44:16 UTC (rev 3345)
+++ trunk/ui/separator/src/main/templates/separator.jspx 2007-10-12 16:09:15 UTC (rev 3346)
@@ -11,7 +11,7 @@
>
<f:clientid var="clientId"/>
<div id="#{clientId}" style="font-size: 0px;"
- x:passThruWithExclusions="id,width,height,style,class">
+ x:passThruWithExclusions="id,width,height,style,class,align,styleClass">
<div style="width: #{this:getWidth(context, component)}; height: #{this:getHeight(context, component)};
background-image: #{this:backgroundImage(context, component)}; background-repeat: repeat-x;
background-position:center; #{component.attributes['style']}"
17 years, 2 months
JBoss Rich Faces SVN: r3345 - trunk/framework/impl/src/main/java/org/ajax4jsf/resource.
by richfaces-svn-commits@lists.jboss.org
Author: alexsmirnov
Date: 2007-10-12 11:44:16 -0400 (Fri, 12 Oct 2007)
New Revision: 3345
Modified:
trunk/framework/impl/src/main/java/org/ajax4jsf/resource/ResourceLifecycle.java
Log:
http://jira.jboss.com/jira/browse/RF-1109
Modified: trunk/framework/impl/src/main/java/org/ajax4jsf/resource/ResourceLifecycle.java
===================================================================
--- trunk/framework/impl/src/main/java/org/ajax4jsf/resource/ResourceLifecycle.java 2007-10-12 14:43:02 UTC (rev 3344)
+++ trunk/framework/impl/src/main/java/org/ajax4jsf/resource/ResourceLifecycle.java 2007-10-12 15:44:16 UTC (rev 3345)
@@ -179,7 +179,7 @@
} else {
// Invoke after phase listeners, in reverse order.
- for (int i = phaseListeners.length - 1; i > 0; i--) {
+ for (int i = phaseListeners.length - 1; i >= 0; i--) {
PhaseListener phaseListener = phaseListeners[i];
invokePhaseListener(phaseListener, phaseEvent, beforePhase);
}
17 years, 2 months
JBoss Rich Faces SVN: r3344 - trunk/docs/userguide/en/src/main/docbook/included.
by richfaces-svn-commits@lists.jboss.org
Author: ochikvina
Date: 2007-10-12 10:43:02 -0400 (Fri, 12 Oct 2007)
New Revision: 3344
Modified:
trunk/docs/userguide/en/src/main/docbook/included/calendar.xml
trunk/docs/userguide/en/src/main/docbook/included/datascroller.xml
trunk/docs/userguide/en/src/main/docbook/included/modalPanel.xml
trunk/docs/userguide/en/src/main/docbook/included/panel.xml
trunk/docs/userguide/en/src/main/docbook/included/panelBar.xml
trunk/docs/userguide/en/src/main/docbook/included/panelBarItem.xml
trunk/docs/userguide/en/src/main/docbook/included/separator.xml
trunk/docs/userguide/en/src/main/docbook/included/simpleTogglePanel.xml
trunk/docs/userguide/en/src/main/docbook/included/spacer.xml
trunk/docs/userguide/en/src/main/docbook/included/togglePanel.xml
trunk/docs/userguide/en/src/main/docbook/included/virtualEarth.xml
Log:
http://jira.jboss.com/jira/browse/RF-920 - varifying the names of classes( to correct screenshot!!!)
Modified: trunk/docs/userguide/en/src/main/docbook/included/calendar.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/calendar.xml 2007-10-12 14:30:58 UTC (rev 3343)
+++ trunk/docs/userguide/en/src/main/docbook/included/calendar.xml 2007-10-12 14:43:02 UTC (rev 3344)
@@ -948,11 +948,15 @@
</thead>
<tbody>
-
<row>
+ <entry>rich-calendar-popup</entry>
+
+ <entry>Defines styles for a popup element</entry>
+ </row>
+ <row>
<entry>rich-calendar-exterior</entry>
- <entry>Defines styles for a popup element</entry>
+ <entry>Defines styles for a popup element exterior</entry>
</row>
<row>
@@ -1004,7 +1008,7 @@
</row>
<row>
- <entry>rich-calendar-current</entry>
+ <entry>rich-calendar-toolfooter</entry>
<entry>Defines styles for a today control date</entry>
</row>
Modified: trunk/docs/userguide/en/src/main/docbook/included/datascroller.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/datascroller.xml 2007-10-12 14:30:58 UTC (rev 3343)
+++ trunk/docs/userguide/en/src/main/docbook/included/datascroller.xml 2007-10-12 14:43:02 UTC (rev 3344)
@@ -353,13 +353,22 @@
</thead>
<tbody>
<row>
+ <entry>rich-datascr</entry>
+ <entry>Defines styles for a wrapper <div> element of a datascroller</entry>
+ </row>
+ <row>
<entry>rich-dtascroller-table</entry>
- <entry>Defines styles for a wrapper table element of the component</entry>
+ <entry>Defines styles for table element of a datascroller</entry>
</row>
<row>
<entry>rich-datascr-button</entry>
<entry>Defines styles for a button</entry>
</row>
+
+ <row>
+ <entry>rich-datascr-ctrls-separator</entry>
+ <entry>Defines styles for a separator between buttons</entry>
+ </row>
</tbody>
</tgroup>
Modified: trunk/docs/userguide/en/src/main/docbook/included/modalPanel.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/modalPanel.xml 2007-10-12 14:30:58 UTC (rev 3343)
+++ trunk/docs/userguide/en/src/main/docbook/included/modalPanel.xml 2007-10-12 14:43:02 UTC (rev 3344)
@@ -505,6 +505,81 @@
</tbody>
</tgroup>
</table>
+ <table>
+ <title>Classes names that define a component appearance</title>
+
+ <tgroup cols="2">
+ <thead>
+ <row>
+ <entry>Class name</entry>
+
+ <entry>Description</entry>
+ </row>
+ </thead>
+
+ <tbody>
+ <row>
+ <entry>rich-modalpanel</entry>
+
+ <entry>Defines styles for a wrapper <div> element of a modalpanel</entry>
+ </row>
+
+ <row>
+ <entry>rich-mpnl_panel</entry>
+
+ <entry>Defines styles for a modalpanel</entry>
+ </row>
+
+ <row>
+ <entry>rich-mpnl-mask-div</entry>
+
+ <entry>Defines styles for a wrapper <div> element of a mask</entry>
+ </row>
+
+ <row>
+ <entry>rich-mpnl-resizer</entry>
+
+ <entry>Defines styles for a wrapper <div> element of a resizing element</entry>
+ </row>
+
+ <row>
+ <entry>rich-mpnl-shadow</entry>
+
+ <entry>Defines styles for a modalpanel shadow</entry>
+ </row>
+
+ <row>
+ <entry>rich-mpnl-header</entry>
+
+ <entry>Defines styles for a modalpanel header</entry>
+ </row>
+
+ <row>
+ <entry>rich-mpnl-header-cell</entry>
+
+ <entry>Defines styles for a header cell</entry>
+ </row>
+
+ <row>
+ <entry>rich-mpnl-text</entry>
+
+ <entry>Defines styles for a wrapper <div> element of a header text</entry>
+ </row>
+
+ <row>
+ <entry>rich-mpnl-body</entry>
+
+ <entry>Defines styles for a modalpanel body</entry>
+ </row>
+
+ <row>
+ <entry>rich-mpnl-controls</entry>
+
+ <entry>Defines styles for a wrapper <div> element of a modalpanel control</entry>
+ </row>
+ </tbody>
+ </tgroup>
+ </table>
<para>In order to redefine styles for all <emphasis role="bold">
<property><rich:modalPanel></property>
</emphasis> components on a page using CSS, it's enough to create classes with the
Modified: trunk/docs/userguide/en/src/main/docbook/included/panel.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/panel.xml 2007-10-12 14:30:58 UTC (rev 3343)
+++ trunk/docs/userguide/en/src/main/docbook/included/panel.xml 2007-10-12 14:43:02 UTC (rev 3344)
@@ -268,7 +268,7 @@
</figure>
<para>On the screenshot, there are classes names that define specified elements.</para>
<table>
- <title>Component skin class</title>
+ <title>Classes names that define a component appearance</title>
<tgroup cols="2">
<thead>
<row>
@@ -279,20 +279,15 @@
<tbody>
<row>
<entry>rich-panel</entry>
- <entry>The class defines a <property>panel</property> common style. It's used
- in the outside <emphasis role="bold">
- <property><div></property>
- </emphasis>element</entry>
+ <entry>Defines styles for a wrapper <div> element of a panel</entry>
</row>
<row>
<entry>rich-panel-header</entry>
- <entry>The class defines a header style. It's applicable for header elements of
- all panels</entry>
+ <entry>Defines styles for header element of a panel</entry>
</row>
<row>
<entry>rich-panel-body</entry>
- <entry>The class defines a content style inside a panel. It's applicable for
- elements inside panels</entry>
+ <entry>Defines styles for a panel body</entry>
</row>
</tbody>
</tgroup>
Modified: trunk/docs/userguide/en/src/main/docbook/included/panelBar.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/panelBar.xml 2007-10-12 14:30:58 UTC (rev 3343)
+++ trunk/docs/userguide/en/src/main/docbook/included/panelBar.xml 2007-10-12 14:43:02 UTC (rev 3344)
@@ -120,7 +120,7 @@
</mediaobject>
</figure>
<table>
- <title>Predefined component skin class</title>
+ <title>Classes names that define a component appearance</title>
<tgroup cols="2">
<thead>
<row>
@@ -131,8 +131,9 @@
<tbody>
<row>
<entry>rich-panelbar</entry>
- <entry>applicable for the whole panelBar (padding, border)</entry>
+ <entry>Defines styles for a wrapper <div> element of a panelbar</entry>
</row>
+
</tbody>
</tgroup>
</table>
Modified: trunk/docs/userguide/en/src/main/docbook/included/panelBarItem.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/panelBarItem.xml 2007-10-12 14:30:58 UTC (rev 3343)
+++ trunk/docs/userguide/en/src/main/docbook/included/panelBarItem.xml 2007-10-12 14:43:02 UTC (rev 3344)
@@ -166,10 +166,10 @@
</imageobject>
</mediaobject>
</figure>
- <para>There are two predefined classes for the <property>panelBarItem</property> shown on the
+ <para>There are three predefined classes for the <property>panelBarItem</property> shown on the
screenshot and described in the table below</para>
<table>
- <title>Predefined component skin class</title>
+ <title>Classes names that define a component appearance</title>
<tgroup cols="2">
<thead>
<row>
@@ -180,11 +180,17 @@
<tbody>
<row>
<entry>rich-panelbar-header</entry>
- <entry>applicable for panelBarItem headers</entry>
+ <entry>Defines styles for a wrapper <div> element of a panelbar item header</entry>
</row>
+
<row>
+ <entry>rich-panelbar-header-act</entry>
+ <entry>Defines styles for a wrapper <div> element of an acting panelbar item header</entry>
+ </row>
+
+ <row>
<entry>rich-panelbar-content</entry>
- <entry>applicable for panelBarItem </entry>
+ <entry>Defines styles for a panelbar item content</entry>
</row>
</tbody>
</tgroup>
Modified: trunk/docs/userguide/en/src/main/docbook/included/separator.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/separator.xml 2007-10-12 14:30:58 UTC (rev 3343)
+++ trunk/docs/userguide/en/src/main/docbook/included/separator.xml 2007-10-12 14:43:02 UTC (rev 3344)
@@ -120,6 +120,7 @@
<property>"styleClass"</property>
</emphasis>) modifying component property.</para>
</section>
+
<section>
<title>Relevant Resources Links</title>
<para>
Modified: trunk/docs/userguide/en/src/main/docbook/included/simpleTogglePanel.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/simpleTogglePanel.xml 2007-10-12 14:30:58 UTC (rev 3343)
+++ trunk/docs/userguide/en/src/main/docbook/included/simpleTogglePanel.xml 2007-10-12 14:43:02 UTC (rev 3344)
@@ -230,7 +230,7 @@
<property><div></property>
</emphasis> element. See the table:</para>
<table>
- <title>Predefined component skin classes</title>
+ <title>Classes names that define a component appearance</title>
<tgroup cols="2">
<thead>
<row>
@@ -241,20 +241,20 @@
<tbody>
<row>
<entry>rich-stglpanel</entry>
- <entry>The class defines a simpleTogglePanel common style. It's used in the
- outside <emphasis role="bold">
- <property><div></property>
- </emphasis>element</entry>
+ <entry>Defines styles for a wrapper <div> element of a simpleTogglePanel</entry>
</row>
<row>
<entry>rich-stglpanel-header</entry>
- <entry>The class defines a header style. It's applicable for header elements of
- all simple toggle panels</entry>
+ <entry>Defines styles for header element of a simpleTogglePanel</entry>
</row>
<row>
+ <entry>rich-stglpanel-marker</entry>
+ <entry>Defines styles for a wrapper <div> element for a marker</entry>
+ </row>
+
+ <row>
<entry>rich-stglpanel-body</entry>
- <entry>The class defines content style inside a panel. It's applicable for
- elements inside simple toggle panels</entry>
+ <entry>Defines styles for a simpleTogglePanel body</entry>
</row>
</tbody>
</tgroup>
Modified: trunk/docs/userguide/en/src/main/docbook/included/spacer.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/spacer.xml 2007-10-12 14:30:58 UTC (rev 3343)
+++ trunk/docs/userguide/en/src/main/docbook/included/spacer.xml 2007-10-12 14:43:02 UTC (rev 3344)
@@ -99,6 +99,7 @@
<property>"styleClass"</property>
</emphasis>) modifying component property.</para>
</section>
+
<section>
<title>Relevant Resources Links</title>
<para>
Modified: trunk/docs/userguide/en/src/main/docbook/included/togglePanel.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/togglePanel.xml 2007-10-12 14:30:58 UTC (rev 3343)
+++ trunk/docs/userguide/en/src/main/docbook/included/togglePanel.xml 2007-10-12 14:43:02 UTC (rev 3344)
@@ -143,7 +143,39 @@
<para>The component doesn't have its own representation rendering only content of its
facets, thus all look and feel is set only for content.</para>
</section>
+
<section>
+ <title>Definition of Custom Style Classes</title>
+ <table>
+ <title>Classes names that define a component appearance</title>
+ <tgroup cols="2">
+ <thead>
+ <row>
+ <entry>Class name</entry>
+ <entry>Class description</entry>
+ </row>
+ </thead>
+ <tbody>
+ <row>
+ <entry></entry>
+ <entry></entry>
+ </row>
+
+ <row>
+ <entry></entry>
+ <entry></entry>
+ </row>
+
+ <row>
+ <entry></entry>
+ <entry></entry>
+ </row>
+ </tbody>
+ </tgroup>
+ </table>
+ </section>
+
+ <section>
<title>Relevant Resources Links</title>
<para>
<ulink url="http://livedemo.exadel.com/richfaces-demo/richfaces/togglePanel.jsf?c=tog..."
@@ -151,5 +183,5 @@
><property><rich:togglePanel></property></emphasis> usage and sources for the given example.
</para>
</section>
-
+
</section>
Modified: trunk/docs/userguide/en/src/main/docbook/included/virtualEarth.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/virtualEarth.xml 2007-10-12 14:30:58 UTC (rev 3343)
+++ trunk/docs/userguide/en/src/main/docbook/included/virtualEarth.xml 2007-10-12 14:43:02 UTC (rev 3344)
@@ -149,7 +149,7 @@
</thead>
<tbody>
<row>
- <entry>Rich-virtualEarth</entry>
+ <entry>rich-virtualEarth</entry>
<entry>Defines styles for a wrapper <div> element for a virtualEarth</entry>
</row>
</tbody>
17 years, 2 months
JBoss Rich Faces SVN: r3343 - in trunk/ui: inputnumber-slider/src/main/templates and 1 other directories.
by richfaces-svn-commits@lists.jboss.org
Author: sergeyhalipov
Date: 2007-10-12 10:30:58 -0400 (Fri, 12 Oct 2007)
New Revision: 3343
Modified:
trunk/ui/dataTable/src/main/templates/org/richfaces/htmlDataGrid.jspx
trunk/ui/dataTable/src/main/templates/org/richfaces/htmlDataList.jspx
trunk/ui/dataTable/src/main/templates/org/richfaces/htmlDataOrderedList.jspx
trunk/ui/inputnumber-slider/src/main/templates/inputNumberSlider.jspx
trunk/ui/separator/src/main/templates/separator.jspx
Log:
http://jira.jboss.com/jira/browse/RF-1108
Modified: trunk/ui/dataTable/src/main/templates/org/richfaces/htmlDataGrid.jspx
===================================================================
--- trunk/ui/dataTable/src/main/templates/org/richfaces/htmlDataGrid.jspx 2007-10-12 14:12:17 UTC (rev 3342)
+++ trunk/ui/dataTable/src/main/templates/org/richfaces/htmlDataGrid.jspx 2007-10-12 14:30:58 UTC (rev 3343)
@@ -15,7 +15,7 @@
<f:clientid var="clientId"/>
<table id="#{clientId}"
class="dr-table rich-table #{component.attributes['styleClass']}"
- x:passThruWithExclusions="value,name,type"
+ x:passThruWithExclusions="value,name,type,class,id"
>
<f:call name="encodeCaption" />
<colgroup span="#{component.attributes['columns']}">
@@ -28,4 +28,4 @@
</vcp:body>
</tbody>
</table>
-</f:root>
\ No newline at end of file
+</f:root>
Modified: trunk/ui/dataTable/src/main/templates/org/richfaces/htmlDataList.jspx
===================================================================
--- trunk/ui/dataTable/src/main/templates/org/richfaces/htmlDataList.jspx 2007-10-12 14:12:17 UTC (rev 3342)
+++ trunk/ui/dataTable/src/main/templates/org/richfaces/htmlDataList.jspx 2007-10-12 14:30:58 UTC (rev 3343)
@@ -12,7 +12,6 @@
>
<f:clientid var="clientId"/>
<ul id="#{clientId}"
- type="#{component.attributes['type']}"
class="dr-list rich-datalist #{component.attributes['styleClass']}"
x:passThruWithExclusions="id,class"
>
@@ -20,4 +19,4 @@
<f:call name="encodeRows"/>
</vcp:body>
</ul>
-</f:root>
\ No newline at end of file
+</f:root>
Modified: trunk/ui/dataTable/src/main/templates/org/richfaces/htmlDataOrderedList.jspx
===================================================================
--- trunk/ui/dataTable/src/main/templates/org/richfaces/htmlDataOrderedList.jspx 2007-10-12 14:12:17 UTC (rev 3342)
+++ trunk/ui/dataTable/src/main/templates/org/richfaces/htmlDataOrderedList.jspx 2007-10-12 14:30:58 UTC (rev 3343)
@@ -12,7 +12,6 @@
>
<f:clientid var="clientId"/>
<ol id="#{clientId}"
- type="#{component.attributes['type']}"
class="dr-list rich-orderedlist #{component.attributes['styleClass']}"
x:passThruWithExclusions="id,class"
>
@@ -20,4 +19,4 @@
<f:call name="encodeRows"/>
</vcp:body>
</ol>
-</f:root>
\ No newline at end of file
+</f:root>
Modified: trunk/ui/inputnumber-slider/src/main/templates/inputNumberSlider.jspx
===================================================================
--- trunk/ui/inputnumber-slider/src/main/templates/inputNumberSlider.jspx 2007-10-12 14:12:17 UTC (rev 3342)
+++ trunk/ui/inputnumber-slider/src/main/templates/inputNumberSlider.jspx 2007-10-12 14:30:58 UTC (rev 3343)
@@ -40,7 +40,7 @@
]]></jsp:scriptlet>
<table id="#{clientId}" border="0" cellpadding="0" cellspacing="0" class="dr-insldr rich-slider #{component.attributes['styleClass']}"
- style="#{style}" x:passThruWithExclusions="id,boundClass,tipClass,class,width,height,style">
+ style="#{style}" x:passThruWithExclusions="id,boundClass,tipClass,class,width,height,style,border">
<tbody>
<tr>
<jsp:scriptlet><![CDATA[
Modified: trunk/ui/separator/src/main/templates/separator.jspx
===================================================================
--- trunk/ui/separator/src/main/templates/separator.jspx 2007-10-12 14:12:17 UTC (rev 3342)
+++ trunk/ui/separator/src/main/templates/separator.jspx 2007-10-12 14:30:58 UTC (rev 3343)
@@ -10,11 +10,11 @@
component="org.richfaces.component.UISeparator"
>
<f:clientid var="clientId"/>
- <div id="#{clientId}" align="#{component.attributes['align']}" style="font-size: 0px;"
+ <div id="#{clientId}" style="font-size: 0px;"
x:passThruWithExclusions="id,width,height,style,class">
<div style="width: #{this:getWidth(context, component)}; height: #{this:getHeight(context, component)};
background-image: #{this:backgroundImage(context, component)}; background-repeat: repeat-x;
background-position:center; #{component.attributes['style']}"
class="rich-separator #{component.attributes['styleClass']}"/>
</div>
-</f:root>
\ No newline at end of file
+</f:root>
17 years, 2 months
JBoss Rich Faces SVN: r3342 - trunk/ui/calendar/src/main/templates/org/richfaces.
by richfaces-svn-commits@lists.jboss.org
Author: akushunin
Date: 2007-10-12 10:12:17 -0400 (Fri, 12 Oct 2007)
New Revision: 3342
Modified:
trunk/ui/calendar/src/main/templates/org/richfaces/htmlCalendar.jspx
Log:
Rf-1105
Modified: trunk/ui/calendar/src/main/templates/org/richfaces/htmlCalendar.jspx
===================================================================
--- trunk/ui/calendar/src/main/templates/org/richfaces/htmlCalendar.jspx 2007-10-12 14:02:05 UTC (rev 3341)
+++ trunk/ui/calendar/src/main/templates/org/richfaces/htmlCalendar.jspx 2007-10-12 14:12:17 UTC (rev 3342)
@@ -75,30 +75,8 @@
}
/*]]>*/</jsp:scriptlet>
-
- <jsp:scriptlet> /*<![CDATA[*/
- if (component.getFacet("optionalHeader")!= null&& component.getFacet("optionalHeader").isRendered()){
- /*]]>*/ </jsp:scriptlet>
- ,headerOptionalMarkup: [new E('b',{},
- <jsp:scriptlet> /*<![CDATA[*/
- writeMarkupScriptBody(context, component.getFacet("optionalHeader"), false);
- /*]]>*/ </jsp:scriptlet>
- )]
- <jsp:scriptlet> /*<![CDATA[*/
- }
- /*]]>*/ </jsp:scriptlet>
-
- <jsp:scriptlet> /*<![CDATA[*/
- if (component.getFacet("optionalFooter")!= null&& component.getFacet("optionalFooter").isRendered()){
- /*]]>*/ </jsp:scriptlet>
- ,footerOptionalMarkup: [new E('b',{},
- <jsp:scriptlet> /*<![CDATA[*/
- writeMarkupScriptBody(context, component.getFacet("optionalFooter"), false);
- /*]]>*/ </jsp:scriptlet>
- )]
- <jsp:scriptlet> /*<![CDATA[*/
- }
- /*]]>*/ </jsp:scriptlet>
+ <f:call name="writeOptionalFacetMarkupScriptBody"><f:parameter value="optionalHeader" /></f:call>
+ <f:call name="writeOptionalFacetMarkupScriptBody"><f:parameter value="optionalFooter" /></f:call>
<f:call name="writeFacetMarkupScriptBody"><f:parameter value="weekDay" /></f:call>
<f:call name="writeFacetMarkupScriptBody"><f:parameter value="weekNumber" /></f:call>
17 years, 2 months
JBoss Rich Faces SVN: r3341 - trunk/ui/calendar/src/main/resources/org/richfaces/renderkit/html/scripts.
by richfaces-svn-commits@lists.jboss.org
Author: pyaschenko
Date: 2007-10-12 10:02:05 -0400 (Fri, 12 Oct 2007)
New Revision: 3341
Modified:
trunk/ui/calendar/src/main/resources/org/richfaces/renderkit/html/scripts/calendar.js
Log:
RF-1105
Modified: trunk/ui/calendar/src/main/resources/org/richfaces/renderkit/html/scripts/calendar.js
===================================================================
--- branches/3.1.x/framework/impl/src/main/resources/org/richfaces/renderkit/html/scripts/utils.js 2007-10-12 13:43:17 UTC (rev 3339)
+++ branches/3.1.x/framework/impl/src/main/resources/org/richfaces/renderkit/html/scripts/utils.js 2007-10-12 13:53:27 UTC (rev 3340)
@@ -121,7 +121,13 @@
//js string evaluation
else {
try {
- value=object.eval(template);
+ if (Richfaces.browser.isObjectEval) {
+ value = object.eval(template);
+ }
+ else with (object) {
+ value = eval(template) ;
+ }
+
if (typeof value == 'function') {
value = value(object);
}
@@ -149,8 +155,10 @@
}
Richfaces.browser= {
+ isIE: (!window.opera && /MSIE/.test(navigator.userAgent)),
isIE6: (!window.opera && /MSIE\s*[6][\d,\.]+;/.test(navigator.userAgent)),
- isSafari: /Safari/.test(navigator.userAgent)
+ isSafari: /Safari/.test(navigator.userAgent),
+ isObjectEval: (Richfaces.eval!=undefined)
};
Richfaces.eval = function(template, object) {
17 years, 2 months
JBoss Rich Faces SVN: r3339 - trunk/framework/impl/src/main/resources/org/richfaces/renderkit/html/scripts.
by richfaces-svn-commits@lists.jboss.org
Author: pyaschenko
Date: 2007-10-12 09:43:17 -0400 (Fri, 12 Oct 2007)
New Revision: 3339
Modified:
trunk/framework/impl/src/main/resources/org/richfaces/renderkit/html/scripts/utils.js
Log:
RF-913
Modified: trunk/framework/impl/src/main/resources/org/richfaces/renderkit/html/scripts/utils.js
===================================================================
--- trunk/framework/impl/src/main/resources/org/richfaces/renderkit/html/scripts/utils.js 2007-10-12 10:26:55 UTC (rev 3338)
+++ trunk/framework/impl/src/main/resources/org/richfaces/renderkit/html/scripts/utils.js 2007-10-12 13:43:17 UTC (rev 3339)
@@ -121,7 +121,13 @@
//js string evaluation
else {
try {
- value=object.eval(template);
+ if (Richfaces.browser.isObjectEval) {
+ value = object.eval(template);
+ }
+ else with (object) {
+ value = eval(template) ;
+ }
+
if (typeof value == 'function') {
value = value(object);
}
@@ -151,7 +157,8 @@
Richfaces.browser= {
isIE: (!window.opera && /MSIE/.test(navigator.userAgent)),
isIE6: (!window.opera && /MSIE\s*[6][\d,\.]+;/.test(navigator.userAgent)),
- isSafari: /Safari/.test(navigator.userAgent)
+ isSafari: /Safari/.test(navigator.userAgent),
+ isObjectEval: (Richfaces.eval!=undefined)
};
Richfaces.eval = function(template, object) {
17 years, 2 months
JBoss Rich Faces SVN: r3338 - branches/3.1.x/ui/dataTable/src/main/templates/org/richfaces.
by richfaces-svn-commits@lists.jboss.org
Author: sergeyhalipov
Date: 2007-10-12 06:26:55 -0400 (Fri, 12 Oct 2007)
New Revision: 3338
Modified:
branches/3.1.x/ui/dataTable/src/main/templates/org/richfaces/htmlColumn.jspx
Log:
http://jira.jboss.com/jira/browse/RF-1091
Modified: branches/3.1.x/ui/dataTable/src/main/templates/org/richfaces/htmlColumn.jspx
===================================================================
--- branches/3.1.x/ui/dataTable/src/main/templates/org/richfaces/htmlColumn.jspx 2007-10-12 07:56:57 UTC (rev 3337)
+++ branches/3.1.x/ui/dataTable/src/main/templates/org/richfaces/htmlColumn.jspx 2007-10-12 10:26:55 UTC (rev 3338)
@@ -13,9 +13,10 @@
component="org.richfaces.component.UIColumn"
>
<f:clientid var="clientId"/>
- <td class="#{this:styleClass(context,component)}"
+ <td id="#{clientId}"
+ class="#{this:styleClass(context,component)}"
x:passThruWithExclusions="value,name,type,id,class"
>
<vcp:body/>
</td>
-</f:root>
\ No newline at end of file
+</f:root>
17 years, 2 months
JBoss Rich Faces SVN: r3337 - trunk/extensions/portlet/src/main/java/org/ajax4jsf/portlet/application.
by richfaces-svn-commits@lists.jboss.org
Author: maksimkaszynski
Date: 2007-10-12 03:56:57 -0400 (Fri, 12 Oct 2007)
New Revision: 3337
Modified:
trunk/extensions/portlet/src/main/java/org/ajax4jsf/portlet/application/PortalStateManager.java
Log:
fixed back to java 1.4
Modified: trunk/extensions/portlet/src/main/java/org/ajax4jsf/portlet/application/PortalStateManager.java
===================================================================
--- trunk/extensions/portlet/src/main/java/org/ajax4jsf/portlet/application/PortalStateManager.java 2007-10-12 01:04:40 UTC (rev 3336)
+++ trunk/extensions/portlet/src/main/java/org/ajax4jsf/portlet/application/PortalStateManager.java 2007-10-12 07:56:57 UTC (rev 3337)
@@ -39,7 +39,7 @@
return new SerializedView(viewId,null);
}
- @Override
+ //@Override
protected Object[] restoreStateFromSession(FacesContext context,
String viewId, String renderKitId) {
Object[] state = new Object[2];
17 years, 2 months
--- trunk/ui/calendar/src/main/resources/org/richfaces/renderkit/html/scripts/calendar.js 2007-10-12 13:53:27 UTC (rev 3340)
+++ trunk/ui/calendar/src/main/resources/org/richfaces/renderkit/html/scripts/calendar.js 2007-10-12 14:02:05 UTC (rev 3341)
@@ -398,8 +398,8 @@
// headerMarkup
// footerMarkup
// headerOptionalMarkup - user defined header (optional)
// footerOptionalMarkup - user defined footer (optional)
// currentDate - date to show month (day not used) (mm/yyyy)
// selectedDate - selected date (mm/dd/yyyy)
@@ -483,8 +483,8 @@
'<input id="'+this.id+'InputCurrentDate" name="'+this.id+'InputCurrentDate" type="hidden" style="display:none" value="'+this.getCurrentDate().format("MM/yyyy")+'"/>\n' +
'<table border="0" cellpadding="0" cellspacing="0" class="rich-calendar-exterior"><tbody>\n';
var colspan = (this.params.showWeeksBar ? "8" : "7");
- var htmlHeaderOptional = (this.params.headerOptionalMarkup) ? '<tr><td class="rich-calendar-header-optional" colspan="'+colspan+'" id="'+this.id+'HeaderOptional"></td></tr>' : '';
- var htmlFooterOptional = (this.params.footerOptionalMarkup) ? '<tr><td class="rich-calendar-footer-optional" colspan="'+colspan+'" id="'+this.id+'FooterOptional"></td></tr>' : '';
+ var htmlHeaderOptional = (this.params.optionalHeaderMarkup) ? '<tr><td class="rich-calendar-header-optional" colspan="'+colspan+'" id="'+this.id+'HeaderOptional"></td></tr>' : '';
+ var htmlFooterOptional = (this.params.optionalFooterMarkup) ? '<tr><td class="rich-calendar-footer-optional" colspan="'+colspan+'" id="'+this.id+'FooterOptional"></td></tr>' : '';
var htmlControlsHeader = '<tr><td class="rich-calendar-header" colspan="'+colspan+'" id="'+this.id+'Header"></td></tr>';
var htmlControlsFooter = '<tr><td class="rich-calendar-footer" colspan="'+colspan+'" id="'+this.id+'Footer"></td></tr>';
var htmlTextFooter = '</tbody></table>\n'
@@ -1168,12 +1168,12 @@
renderHeaderOptional: function()
{
- this.renderMarkup(this.params.headerOptionalMarkup, this.id+"HeaderOptional", this.calendarContext);
+ this.renderMarkup(this.params.optionalHeaderMarkup, this.id+"HeaderOptional", this.calendarContext);
},
renderFooterOptional: function()
{
- this.renderMarkup(this.params.footerOptionalMarkup, this.id+"FooterOptional", this.calendarContext);
+ this.renderMarkup(this.params.optionalFooterMarkup, this.id+"FooterOptional", this.calendarContext);
},
renderMarkup: function (markup, elementId, context)
17 years, 2 months
@@ -398,8 +398,8 @@
// headerMarkup
// footerMarkup
- // headerOptionalMarkup - user defined header (optional)
- // footerOptionalMarkup - user defined footer (optional)
+ // optionalHeaderMarkup - user defined header (optional)
+ // optionalFooterMarkup - user defined footer (optional)
// currentDate - date to show month (day not used) (mm/yyyy)
// selectedDate - selected date (mm/dd/yyyy)
JBoss Rich Faces SVN: r3340 - branches/3.1.x/framework/impl/src/main/resources/org/richfaces/renderkit/html/scripts.
by richfaces-svn-commits@lists.jboss.org
Author: pyaschenko
Date: 2007-10-12 09:53:27 -0400 (Fri, 12 Oct 2007)
New Revision: 3340
Modified:
branches/3.1.x/framework/impl/src/main/resources/org/richfaces/renderkit/html/scripts/utils.js
Log:
RF-913
Modified: branches/3.1.x/framework/impl/src/main/resources/org/richfaces/renderkit/html/scripts/utils.js
===================================================================